==> mumble_1.1.4.orig.tar.gz: mumble-1.1.4/src/Connection.h <==
/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>

   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright notice,
     this list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
   - Neither the name of the Mumble Developers nor the names of its
     contributors may be used to endorse or promote products derived from this
     software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef _CONNECTION_H
#define _CONNECTION_H

#include "murmur_pch.h"
#include "CryptState.h"

class Message;

class Connection : public QObject {
		Q_OBJECT
	private:
		static int iReceiveLevel;
		static QSet<Connection *> qsReceivers;
	protected:
		QSslSocket *qtsSocket;
		QTime qtLastPacket;
		int iPacketLength;
		bool bDisconnectedEmitted;
	protected slots:
		void socketRead();
		void socketError(QAbstractSocket::SocketError);
		void socketDisconnected();
		void socketSslErrors(const QList<QSslError> &errors);
	public slots:
		void proceedAnyway();
	signals:
		void connectionClosed(QString reason);
		void message(QByteArray &);
		void handleSslErrors(const QList<QSslError> &);

		void recheckBuffer();
	public:
		Connection(QObject *parent, QSslSocket *qtsSocket);
		~Connection();
		void sendMessage(const Message *mMsg);
		void sendMessage(const QByteArray &qbaMsg);
		void disconnectSocket();
		void forceFlush();
		int activityTime() const;

		CryptState csCrypt;

		double dUDPPingAvg;
		double dUDPPingVar;
		quint32 uiUDPPackets;
		double dTCPPingAvg;
		double dTCPPingVar;
		quint32 uiTCPPackets;

		static void updatePing(double &avg, double &var, quint32 &samples, quint64 usec);

		QList<QSslCertificate> peerCertificateChain() const;
		QSslCipher sessionCipher() const;
		QHostAddress peerAddress() const;
		quint16 peerPort() const;
};

#else
class Connection;
#endif

==> mumble_1.1.6.orig.tar.gz: mumble-1.1.6/src/Connection.h <==
/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>

   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright notice,
     this list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
   - Neither the name of the Mumble Developers nor the names of its
     contributors may be used to endorse or promote products derived from this
     software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef _CONNECTION_H
#define _CONNECTION_H

#include "murmur_pch.h"
#include "CryptState.h"

class Message;

class Connection : public QObject {
		Q_OBJECT
	private:
		static int iReceiveLevel;
		static QSet<Connection *> qsReceivers;
	protected:
		QSslSocket *qtsSocket;
		QTime qtLastPacket;
		int iPacketLength;
		bool bDisconnectedEmitted;
	protected slots:
		void socketRead();
		void socketError(QAbstractSocket::SocketError);
		void socketDisconnected();
		void socketSslErrors(const QList<QSslError> &errors);
	public slots:
		void proceedAnyway();
	signals:
		void connectionClosed(QString reason);
		void message(QByteArray &);
		void handleSslErrors(const QList<QSslError> &);

		void recheckBuffer();
	public:
		Connection(QObject *parent, QSslSocket *qtsSocket);
		~Connection();
		void sendMessage(const Message *mMsg);
		void sendMessage(const QByteArray &qbaMsg);
		void disconnectSocket(bool force=false);
		void forceFlush();
		int activityTime() const;

		CryptState csCrypt;

		double dUDPPingAvg;
		double dUDPPingVar;
		quint32 uiUDPPackets;
		double dTCPPingAvg;
		double dTCPPingVar;
		quint32 uiTCPPackets;

		static void updatePing(double &avg, double &var, quint32 &samples, quint64 usec);

		QList<QSslCertificate> peerCertificateChain() const;
		QSslCipher sessionCipher() const;
		QHostAddress peerAddress() const;
		quint16 peerPort() const;
};

#else
class Connection;
#endif
